Crate bignumbe_rs_macro

Crate bignumbe_rs_macro 

Macros

create_efficient_base
Called like create_efficient_base(n), where n is the number of the base
make_bignum
Called like create_efficient_base(n, (pub) IntName), where n is the number of the base and IntName is the name of the type you want to create, with optional visibility qualifiers